@@ -224,9 +224,7 @@ static void server_real_connect(SERVER_REC *server, IPADDR *ip,
 		port = server->connrec->proxy != NULL ?
 			server->connrec->proxy_port : server->connrec->port;
 		handle = server->connrec->use_ssl ?
-			net_connect_ip_ssl(ip, port, server->connrec->address, own_ip, server->connrec->ssl_cert, server->connrec->ssl_pkey,
-server->connrec->ssl_cafile, server->connrec->ssl_capath, server->connrec->ssl_verify) :
-			net_connect_ip(ip, port, own_ip);
+			net_connect_ip_ssl(ip, port, own_ip, server) : net_connect_ip(ip, port, own_ip);
 	} else {
 		handle = net_connect_unix(unix_socket);
 	}
@@ -419,8 +417,8 @@ int server_start_connect(SERVER_REC *server)
 			return FALSE;
 		}
 
-		server->connect_pipe[0] = g_io_channel_unix_new(fd[0]);
-		server->connect_pipe[1] = g_io_channel_unix_new(fd[1]);
+		server->connect_pipe[0] = g_io_channel_new(fd[0]);
+		server->connect_pipe[1] = g_io_channel_new(fd[1]);
 
 		connect_address = server->connrec->proxy != NULL ?
 			server->connrec->proxy : server->connrec->address;
@@ -637,6 +635,7 @@ void server_connect_unref(SERVER_CONNECT_REC *conn)
 
 	g_free_not_null(conn->ssl_cert);
 	g_free_not_null(conn->ssl_pkey);
+	g_free_not_null(conn->ssl_pass);
 	g_free_not_null(conn->ssl_cafile);
 	g_free_not_null(conn->ssl_capath);
 
