@@ -533,7 +533,7 @@ static char *line_get_command(const char *line, char **args, int aliases)
 	} while (ptr != NULL);
 
         if (cmd != NULL)
-		g_strdown(cmd);
+		ascii_strdown(cmd);
 	return cmd;
 }
 
