@@ -31,7 +31,8 @@
 
 /* Add new nick to list */
 NICK_REC *irc_nicklist_insert(IRC_CHANNEL_REC *channel, const char *nick,
-			      int op, int halfop, int voice, int send_massjoin)
+			      int op, int halfop, int voice, int send_massjoin,
+			      const char *prefixes)
 {
 	NICK_REC *rec;
 
@@ -46,6 +47,10 @@ NICK_REC *irc_nicklist_insert(IRC_CHANNEL_REC *channel, const char *nick,
 	if (voice) rec->voice = TRUE;
 	rec->send_massjoin = send_massjoin;
 
+	if (prefixes != NULL) {
+		strocpy(rec->prefixes, prefixes, sizeof(rec->prefixes));
+	}
+
 	nicklist_insert(CHANNEL(channel), rec);
 	return rec;
 }
@@ -98,7 +103,7 @@ static void event_names_list(IRC_SERVER_REC *server, const char *data)
 {
 	IRC_CHANNEL_REC *chanrec;
 	NICK_REC *rec;
-	char *params, *type, *channel, *names, *ptr;
+	char *params, *type, *channel, *names, *ptr, *host;
         int op, halfop, voice;
 	char prefixes[MAX_USER_PREFIXES+1];
 
@@ -157,10 +162,15 @@ static void event_names_list(IRC_SERVER_REC *server, const char *data)
                         ptr++;
 		}
 
+		host = strchr(ptr, '!');
+		if (host != NULL)
+			*host++ = '\0';
+
 		if (nicklist_find((CHANNEL_REC *) chanrec, ptr) == NULL) {
 			rec = irc_nicklist_insert(chanrec, ptr, op, halfop,
-						  voice, FALSE);
-			memcpy(rec->prefixes, prefixes, sizeof(rec->prefixes));
+						  voice, FALSE, prefixes);
+			if (host != NULL)
+				nicklist_set_host(CHANNEL(chanrec), rec, host);
 		}
 	}
 
@@ -187,7 +197,7 @@ static void event_end_of_names(IRC_SERVER_REC *server, const char *data)
 			nicks = g_hash_table_size(chanrec->nicks);
 			ownnick = irc_nicklist_insert(chanrec, server->nick,
 						      nicks == 0, FALSE,
-						      FALSE, FALSE);
+						      FALSE, FALSE, NULL);
 		}
 		nicklist_set_own(CHANNEL(chanrec), ownnick);
                 chanrec->chanop = chanrec->ownnick->op;
